@@ -159,8 +159,10 @@ panel_position_applet_menu (GtkMenu   *menu,
 
 	gdk_window_get_origin (widget->window, &menu_x, &menu_y);
 
-	menu_x += widget->allocation.x;
-	menu_y += widget->allocation.y;
+	if (GTK_WIDGET_NO_WINDOW (widget)) {
+		menu_x += widget->allocation.x;
+		menu_y += widget->allocation.y;
+	}
 
 	if (PANEL_WIDGET (widget->parent)->orient == GTK_ORIENTATION_HORIZONTAL) {
 		if (menu_y > gdk_screen_get_height (screen) / 2)
@@ -191,23 +193,9 @@ get_default_menu_flags (void)
 	if (distribution != DISTRIBUTION_UNKNOWN)
 		flags |= MAIN_MENU_DISTRIBUTION_SUB;
 
-	/*guess KDE menus*/
-	if (g_file_test (kde_menudir, G_FILE_TEST_IS_DIR))
-		flags |= MAIN_MENU_KDE_SUB;
-
 	return flags;
 }
 
-gboolean
-got_kde_menus (void)
-{
-	/*guess KDE menus*/
-	if (g_file_test (kde_menudir, G_FILE_TEST_IS_DIR))
-		return TRUE;
-	else
-		return FALSE;
-}
-
 gboolean
 got_distro_menus (void)
 {
@@ -217,25 +205,3 @@ got_distro_menus (void)
 	else
 		return FALSE;
 }
-
-GtkWidget *
-stock_menu_item_new (const char *text,
-		     const char *stock_id,
-		     gboolean    force_image)
-{
-        GtkWidget *item;
-        GtkWidget *label;
-
-        item = gtk_image_menu_item_new ();
-
-        panel_load_menu_image_deferred (
-		item, panel_menu_icon_get_size (), stock_id, NULL, NULL, force_image);
-
-        if (text) {
-                label = gtk_label_new_with_mnemonic (text);
-                gtk_misc_set_alignment (GTK_MISC (label), 0.0, 0.5);
-                gtk_container_add (GTK_CONTAINER (item), label);
-        }
-
-        return item;
-}
