@@ -337,7 +337,7 @@ panel_popup_menu (PanelToplevel *toplevel,
 			     gtk_window_get_screen (GTK_WINDOW (toplevel)));
 
 	gtk_menu_popup (GTK_MENU (menu), NULL, NULL,
-			panel_menu_position, panel_widget, button, activate_time);
+			panel_menu_position, toplevel, button, activate_time);
 
 	return TRUE;
 }
@@ -1204,6 +1204,7 @@ static void
 panel_deletion_destroy_dialog (GtkWidget *widget,
 			       PanelToplevel *toplevel)
 {
+	panel_toplevel_unblock_auto_hide (toplevel);
 	g_object_set_data (G_OBJECT (toplevel), "panel-delete-dialog", NULL);
 }
 
@@ -1285,5 +1286,7 @@ panel_delete (PanelToplevel *toplevel)
 		return;
 	}
 
+	panel_toplevel_block_auto_hide (toplevel);
+
 	panel_query_deletion (toplevel);
 }
